GOOF----LE-4-2.0ě      ] 4     h2#      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  owner-report		 	
g  filenameS	f  owner-report.scm	g  set-current-module	
 	 	g  process-use-modules	 	 	g  srfi	g  srfi-1	 	 	g  
gnc-module	 	 	g  main	 	 	g  gettext	 	 	g  gnc:module-load	 f  gnucash/report/report-system	!g  standard-reports	"! 	#" 	$g  business-reports	%$ 	&% 	'f  From	(g  optname-from-date	)f  To	*g  optname-to-date	+f  Due or Post Date	,g  optname-date-driver	-f   08ae9c2e884b4f9787144f47eacd7f44	.g  employee-report-guid	/f   d7d1e53505ee4b1b82efad9eacedaea0	0g  vendor-report-guid	1f   c146317be32e4948a561ec7fc89d15c1	2g  customer-report-guid	3f  Account	4g  acct-string	5g  gnc:pagename-general	6g  
owner-page	7f  Date	8g  date-header	9f  Due Date	:g  due-date-header	;f  	Reference	<g  reference-header	=f  Type	>g  type-header	?f  Description	@g  desc-header	Af  Credits	Bg  
credit-header	Cf  Debits	Dg  debit-header	Ef  Amount	Fg  
amount-header	Gg  GNC-OWNER-CUSTOMER	Hf  Customer	Ig  GNC-OWNER-EMPLOYEE	Jf  Employee	Kf  Company	Lg  owner-string	Mg  _	Nf  No valid customer selected.	Of  No valid employee selected.	Pf  No valid company selected.	Qg  invalid-selection-title-string	Rf  /This report requires a customer to be selected.	Sf  /This report requires a employee to be selected.	Tf  .This report requires a company to be selected.	Ug  invalid-selection-string	Vg  gnc:html-make-generic-warning	Wg  gnc:html-make-no-owner-warning	Xf  No valid account selected	Yf  4This report requires a valid account to be selected.	Zg  &gnc:html-make-no-valid-account-warning	[f  Vendor	\g  doctype-str	]g  make-syntax-transformer	^] 	_] 	`g  addto!	ag  macro	bg  $sc-dispatch	cb 	db 	eg  any	fMe	gg  
syntax->datum	hg 	ig 	jg  
datum->syntax	kj 	lj 	mg  set!	ng  cons	og  syntax-violation	po 	qo 	rf  -source expression failed to match any pattern	sg  gnc:html-table-num-rows	tg  gnc:html-table-set-row-style!	ug  set-last-row-style!	vg  date-col	wg  date-due-col	xg  num-col	yg  type-col	zg  memo-col	{g  
credit-col	|g  	debit-col	}g  	value-col	~g  columns-used-size	g  make-vector g  gnc:option-value g  gnc:lookup-option f  Display Columns g  build-column-used g  reverse g  make-heading-list g  num-buckets g  gnc-numeric-zero g  new-bucket-vector g  decdate g  ThirtyDayDelta g  gnc:make-date-list g  make-interval-list g  incdate g  	YearDelta g  make-extended-interval-list g  xaccQueryGetLots g  QUERY-TXN-MATCH-ANY g  gnc:make-html-table g  
vector-length g  	gnc:error f  "sanity check failed in find-bucket g  gnc:timepair-lt g  gnc-numeric-add-fixed g  for-each g  gnc-lot-get-balance g  gncInvoiceGetInvoiceFromLot g  postdate g  gncInvoiceGetDatePosted g  gncInvoiceGetDateDue g  gnc-numeric-zero-p g  gnc-numeric-neg g  gnc:html-table-set-col-headers! f  Current f  	0-30 days f  
31-60 days f  
61-90 days f  91+ days g  gnc:html-table-append-row! g  map g  gnc:make-gnc-monetary g  vector->list g  make-aging-table g  gnc-print-date f    g  gnc:make-html-table-cell/markup f  number-cell g  make-row f  Balance g  xaccTransGetCurrency f  
normal-row f  
alternate-row g  !gnc:html-table-append-row/markup! g  add-balance-row g  xaccTransGetTxnType g  gnc-transaction-get-date-posted g  xaccTransGetAccountValue g  xaccTransGetSplit g  gncInvoiceGetInvoiceFromTxn g  TXN-TYPE-INVOICE f  Unknown g  gnc:make-html-text g  gnc:html-markup-anchor g  gnc:invoice-anchor-text g  gncInvoiceGetTypeString g  TXN-TYPE-PAYMENT g  gnc:split-anchor-text f  Payment g  gnc:timepair-le g  gnc-get-num-action g  xaccSplitGetMemo g  gnc-numeric-negative-p g  add-txn-row g  xaccQueryGetTransactions g  xaccAccountGetCommodity f  __reg f  reverse? g  sort g  xaccTransOrder f  grand-total g  append f  total-label-cell f  
Period Totals g  $gnc:make-html-table-cell/size/markup f  total-number-cell g  gnc:make-html-table-cell/size f  Total Credit f  	Total Due g  list->vector g  make-txn-table g  gnc:new-options g  gnc:make-simple-boolean-option g  gnc:register-option g  gnc:make-owner-option f  v f  The company for this report. g  gnc:make-internal-option f  
owner-type g  #gnc:make-account-sel-limited-option f  w f  'The account to search for transactions. g  gnc:options-add-date-interval! f  a g  gnc:option-set-value g  relative g  today f  b f  Display the transaction date? f  c f  d f  "Display the transaction reference? f  g f  Display the transaction type? f  ha f  $Display the transaction description? f  haa f  "Display the period credits column? f  hab f  Display a period debits column? f  hb f  Display the transaction amount? g  gnc:make-string-option f  Today Date Format f  p f  <The format for the date->string conversion for today's date. g   gnc-default-strftime-date-format g  gnc:make-multichoice-option f  k f  
Leading date.g  duedatef  Due date is leading.f  	Post Datef  Post date is leading.g  gnc:options-set-default-sectionf  Generalg  options-generatorg  ACCT-TYPE-RECEIVABLE	g  customer-options-generator
g  ACCT-TYPE-PAYABLEg  GNC-OWNER-VENDORg  vendor-options-generator
g  employee-options-generatorg  
take-whileg  
drop-whileg  
string-appendg  list->stringg  string->listg  
string-expandg  gncOwnerReturnGUIDg  gncOwnerGetEndOwnerg  qof-query-add-guid-matchg  SPLIT-TRANSg  INVOICE-FROM-TXNg  
INVOICE-OWNERg  
OWNER-PARENTGg  QOF-QUERY-ORg  	SPLIT-LOTg  OWNER-FROM-LOTg  INVOICE-FROM-LOTg  xaccQueryAddSingleAccountMatch g  
QOF-QUERY-AND!g  xaccQueryAddDateMatchTS"g  qof-query-set-book#g  gnc-get-current-book$g  setup-query%g  gnc:html-table-set-style!&f  table'g  	attribute(f  border)f  cellspacing*f  cellpadding+g  "gnc:owner-get-name-and-address-dep,f  <br>-f  td.f  valign/f  top0g  make-owner-table1f  :&nbsp;2f  &nbsp;3g  make-date-row!4g  make-date-table5g  qof-book-get-slots6g  kvp-frame-get-slot-path-gslist7g  gnc:*kvp-option-path*8g  gnc:*business-label*9g  gnc:*company-name*:g  gnc:*company-addy*;f  align<f  right=g  strftime>g  	localtime?g  
gnc:get-today@g  make-myname-tableAg  gnc:html-document-add-object!Bg  gnc:html-markup-brCg  make-break!Dg  gnc:make-html-documentEg  qof-query-create-for-splitsFg  gnc:report-optionsGg  gnc:timepair-start-day-timeHg  gnc:date-option-absolute-timeIg  gnc:timepair-end-day-timeJf   Kf  ReportLg  gncOwnerIsValidMf  : Ng  gncOwnerGetNameOg  
gnc:report-idPg  gnc:html-document-set-title!Qg  gnc:html-document-set-headline!Rg  gnc:html-markupSf  !Tf  Report:Ug  gnc:owner-anchor-textVf  
Date RangeWf   - Xg  qof-query-destroyYg  reg-rendererZg  gnc-account-nth-child[g  xaccAccountGetType\g  gnc-get-current-root-account]g  gnc-account-n-children^g  find-first-account_g  gncOwnerGetType`g  
GNC-OWNER-JOBag  find-first-account-for-ownerbg  gnc:define-reportcg  versiondg  nameef  Customer Reportfg  report-guidgg  	menu-pathhg  gnc:menuname-business-reportsig  rendererjg  in-menu?kf  
Vendor Reportlf  Employee Reportmg  gnc:make-report-optionsng  gnc:make-reportog  owner-report-create-internalpg  owner-report-createqg  gncOwnerNewrg  gnc:owner-from-splitsg  gnc:owner-report-createtg  gncOwnerFreeug   gnc:owner-report-create-internalvg  gnc:register-report-hookwg  call-with-deferred-observersxw yw zg  module-export!{z |z }g  current-module~} } ap C 5 hr  j  ]4	
5 4 >  "  G   4 >  "  G  4 >  "  G  4 >  "  G  4 >  "  G  4i 
>  "  G  4# >  "  G  4& >  "  G  '(R)*R+,R-.R/0R12R34R5i6R78R9:R;<R=>R?@RABRCDREFRGHIJK h       ] $  C $  CC          g  
owner-type
		  g  filenamef  owner-report.scm
	D
		E				E		
	E	2		F				E			F	2		H	 			  g  nameg  owner-string CLRGMNIOP h(      ] $  6 $  66         g  
owner-type
		&  g  filenamef  owner-report.scm
	K
		L				L			L	1		L	.		M				L			M	1	 	M	.	$	O		&	O	 		&  g  nameg  invalid-selection-title-string CQRGMRIST       h(      ] $  6 $  66         g  
owner-type
		&  g  filenamef  owner-report.scm
	Q
		R				R			R	1		R	.		S				R			S	1	 	S	.	$	U		&	U	 		&  g  nameg  invalid-selection-string CURVQU   h      ] 6         g  report-title-string
		 g  	report-id		  g  filenamef  owner-report.scm
	X
		Z	 			  g  nameg  gnc:html-make-no-owner-warning CWRVMXY   h      ] 45456       g  report-title-string
		 g  	report-id		  g  filenamef  owner-report.scm
	`
			e		
	e			e			f			f			f			b	 				  g  nameg  &gnc:html-make-no-valid-account-warning CZRGMHIJ[       h(      ] $  6 $  66         g  
owner-type
		&  g  filenamef  owner-report.scm
	j
		k				k			k	1		k	.		l				k			l	1	 	l	.	$	n		&	n	 		&  g  nameg  doctype-str C\R4_`adfilmn h   s   ]    C     k       g  alist
		 g  element		  g  filenamef  owner-report.scm
	p
		q	 			   C  h   d   ]	4 5L 4?6\       g  args
		 g  v			  g  filenamef  owner-report.scm		p
 		   Cqr     h(   b   ]	4 5$   O @ 6 Z       g  y
		' g  tmp		'  g  filenamef  owner-report.scm
	p
 		'   C5`Rst h(      - 1 3  4 5@             g  table
			" g  tag			" g  rest				" g  arg-list			"  g  filenamef  owner-report.scm
	s
		v			v			w			v			u				t		"	x	 				"	
	  g  nameg  set-last-row-style! CuR h   z   ] 
C r       g  columns-used
		  g  filenamef  owner-report.scm
	z
		{	 		  g  nameg  date-col CvR h   ~   ] C v       g  columns-used
		  g  filenamef  owner-report.scm
	|
		}	 		  g  nameg  date-due-col CwR     h   y   ] 	Cq       g  columns-used
		  g  filenamef  owner-report.scm
	~
			 		  g  nameg  num-col CxR  h   |   ] 	Ct       g  columns-used
		  g  filenamef  owner-report.scm
 
	 	 		  g  nameg  type-col CyR       h   |   ] 	Ct       g  columns-used
		  g  filenamef  owner-report.scm
 
	 	 		  g  nameg  memo-col CzR       h   ~   ] 	Cv       g  columns-used
		  g  filenamef  owner-report.scm
 
	 	 		  g  nameg  
credit-col C{R     h   }   ] 	Cu       g  columns-used
		  g  filenamef  owner-report.scm
 
	 	 		  g  nameg  	debit-col C|R      h   }   ] 	Cu       g  columns-used
		  g  filenamef  owner-report.scm
 
	 	 		  g  nameg  	value-col C}R	~R~    h       ] $  L MMNCL C         g  used?
		 g  index		  g  filenamef  owner-report.scm
 		 		 		 		 		 	 			   C8:<>@BDF       hh    ]45
HO 444 55
>  "  G  444 55>  "  G  4	44 55	>  "  G  4
44 55	>  "  G  444 55	>  "  G  444 55	>  "  G  4
44 55	>  "  G  444 55	>  "  G  C        g  options
	f g  
col-vector	
f g  col		
	 g  set-col		f g  name		"	7 g  name		J	_ g  name		r  g  name	   g  name	   g  name	  g  name	+ g  name	?T  g  filenamef  owner-report.scm
 
	 		
 		
 		 		 		" 	
	% 		( 		. 		2 		4 		= 		F 		J 	
	M 		P 		V 		Z 		\ 		e 		n 		r 	
	u 		x 		~ 	  	  	  	  	  	
  	  	  	  	  	  	  	  	
  	  	  	  	  	  	  	  	
  	  	  	  	  		 	 	 	
 	 	" 	& 	( 	2 	; 	? 	
B 	E 	K 	O 	Q 	[ 	 F	f  g  nameg  build-column-used CRvM8w:x<y>z@{B|D}F   h     ]	H4 5$  45JK"   4 5$  45JK"   4 5$  45JK"   4 5$  4	5JK"   4
 5$  45JK"   4 5$  4
5JK"   4 5$  45JK"   4 5$  45JK"   J6           g  
column-vector
	  g  heading-list	   g  filenamef  owner-report.scm
 
	 		 		 		 		 		 		! 		+ 		, 		7 		< 		F 		G 		R 		W 		a 		b 		m 		r 		| 		} 	  	  	  	  	  	  	  	  	  	  	  	  	  	  	 %	   g  nameg  make-heading-list CR	R    h   s   ] 45 6   k       g  filenamef  owner-report.scm
 
	 		
 	 		
  g  nameg  new-bucket-vector CR        h8      ]	 H4J5K4J5K4J5KJ 6              g  to-date
		1 g  	begindate		1  g  filenamef  owner-report.scm
 
	 		 		 		 		 		 		' 		1 	 
		1  g  nameg  make-interval-list CR   h0      ]HH4 5K44 55KJJ6             g  to-date
		* g  
dayforcurrent		* g  oldintervalreversed			*  g  filenamef  owner-report.scm
 
		 		 	 	 	)	 	 	( 	
	* 	 		*  g  nameg  make-extended-interval-list CR    hH   (  ] 45$  6 45$   C  "              g  current-bucket
		A g  bucket-intervals		A g  date			A g  current-bucket			)  g  filenamef  owner-report.scm
 		 		 		 		 		 		 		 		 		- 		3 		A 	 
		A	  g  nameg  find-bucket C  h(      ]4L 
L 54L5LC          g  date
		% g  value		% g  bucket-index			% g  	new-value			%  g  filenamef  owner-report.scm
 		 		 		 		 	
	 		 		# 	 			%	  g  nameg  
apply-invoice C 	     hp   K  ]!4 5H4 5L &  45"  454J5$  CL$  
4J5K"   (  J4M5NCLJ6 C      g  lot
		o g  bal			o g  invoice			o g  date		.	o g  value		X	g  g  filenamef  owner-report.scm
 		 			 		 		 		 	'	 		 		( 		. 		1 		; 		C 		D 		L 		V 		X 		[ 		e 		o 	
 		o   CM   h   a   ]L  6      Y       g  entry
		
  g  filenamef  owner-report.scm
		
	
 		
   C  h     ]64545 45 45 	HO 
O 
Q 

Q 4	O >  "  G  4
	454
5454545 >  "  G  4	44O 4555>  "  G  	C        g  options
	  g  query	  g  bucket-intervals		  g  reverse?		  g  	date-type		  g  currency		  g  lots		  g  buckets		  g  payments		  g  table			  g  find-bucket	
	4  g  
apply-invoice		4   g  filenamef  owner-report.scm
 
	 		 	
	 		 		 		C 		b 		g 		k 		m 		n 		r 		t 		u 		y 	
	{ 		| 	  	
  	  	  	
  	  	  	 	 	 	 	 	 	 	 !	 	  g  nameg  make-aging-table CRvwxyz{|} 
h     , 	3 
H	4 5$  45J	K	"   4 5$  ,$  

$  "  45"  J	K	"   4 5$  J	K	"   4 5$  J	K	"   4 5$  J	K	"   4 5$  4	
5J	K	"   4 5$  4	
5J	K	"   4 5$  4	
5J	K	"   J	C       g  
column-vector
	  g  date	  g  due-date		  g  num		  g  type-str		  g  memo		  g  monetary		  g  credit		  g  debit		  g  row-contents			   
g  filenamef  owner-report.scm

					
						 		%		/		5			:	$	;		?	
	A	
	F	
	R	
	W		\		f		m		r		|	 	 	 	 	 	 	 		 	* 		 	  	  	 "		 "	* "		 !	 #	 #	 %		 %	* %		 $	 -	 		  g  nameg  make-row CR}M 
h   E  ]HHJ$  "  K45$  45$  "  o44544555	J$  	"  
H4 J45>  "  G  JKJ$  	"  
K"   JC =      g  table
	
  g  
column-vector	
  g  txn		
  g  odd-row?		
  g  printed?		
  g  
start-date		
  g  total		
  g  row		f  g  	row-style		f   	g  filenamef  owner-report.scm
.
	/		1		2	
	"2		#2	,	-2		23		;3	9	<3	<	@3	?	B3	<	D3	J	E4		H4	(	R4		T4	J	V4	M	X3		^5		`5	"	f5	/	f3		k6	
	r6	=	}6	
 7	 7	
 8	 8	' 8	4 8	
 !	 	  g  nameg  add-balance-row CRM        h    , 	3 HH45	45
H45H4
5
4545	$  -(  4	5"  4
4454
555"  ,	$  4
44
54555"  4	5$  
4J5K"   4
5$  4 JJ5K(  "  	45K4
J4
54
54J54J5$  "  	4J54J5$  
4J5"  5	J$  "  4 45>  "  G  JK"   JJJ C        g  table
	 g  txn	 g  acc		 g  
column-vector		 g  odd-row?		 g  printed?		 g  reverse?		 g  
start-date		 g  total		 g  type			 g  date	
	 g  due-date		! g  value		, g  split	
	6 g  invoice		? g  currency		H g  type-str	  g  row	^ g  	row-style	^  g  filenamef  owner-report.scm
B
	D		D		E		D		$G		,D		/H		6D		9I		?D		BJ		HD		OM		SL		YN		ZS		^S		`S		eO		hP			kQ	
	rR	
	zP			|O	 T	 L	 U	 V		 W	
 W	( W	+ W	( V		 U	 X	
 X	 X	
 D	 [	 \	 \	 ^	 ^	 b	 b	 e	 f	 f	
 h	 h	7i	j	k	%k	'l	6,l	5m	?m	@n	Nn	6Ph	Vp	Xp	 ^p	-^h	cr	js	ur	u	u	x	 I			  g  nameg  add-txn-row CR     h   u   ]
4 5C  m       g  a
		 g  b		  g  filenamef  owner-report.scm
			-	
	( 			   C h     ]4 5$  "  $  s4L	 LLMM LLM5	N M $  9M$  /45$  4M5N"  
4M5N"   "   4M5NNCC        g  txn
	  g  type		  g  t			% g  result		@   g  filenamef  owner-report.scm
											"		)		*		@		E		G	
	M	
	S		T		Y	$	\		`		a		h	5	k		m		r		y	7	|		~	 	 	3 	 	
 	 	
  	    C{|M}zyxwv~ .h    ]V454 545 45 45 4545 44 	
55
H
H	HH445>  "  G  4
J5KHH4
	
O 
J>  "  G  J(  "  4JJJJ>  "  G  45$  "  45$ 6444455 
HH45$  "444J
J	555JK"   45$  44J	55JK"   45$  44J
55JK"   4 5$  	JK"   4!5$  	JK"   4"5$  	JK"   4#5$  	JK"   4$5$  	JK"   J	$  4%J&5JK"   J5>  "  G  "   45$  _4444'J5$  4(5"  4)55 4454J55 5>  "  G  "   4*4+5544%,4- 
55 >  "  G  C 
      g  options
	 g  query	 g  acc		 g  
start-date		 g  end-date		 g  	date-type		 g  txns		= g  used-columns		= g  total		= g  debit			= g  credit	
	= g  currency		= g  table		= g  reverse?	
	= g  printed?		s  g  odd-row?		s  g  t	   g  row-contents	 g  pre-span	 g  interval-vec	  g  filenamef  owner-report.scm
|
	}		~								"		)		.		1	 	7	;	9		;	 	=		=}		N		S		^		g		q		s		x	 	 	 	* 	 	 	 	& 	 	 	 	 											
	 	
&	'	
,	*6	
8	
=	#B	
L	M	
S	T	
^	
c	#h	
r	s	
y	z	
	
	$	
		1	"	
		1	"	
		0	!	
		5	&	
		1	"	
		/	P	_	/
			*	4	5	;	<	?	C	D	N	O	S	U	Z	^	`	b	e	f	j	r	s	}							'					
	
	
		 		  g  nameg  make-txn-table CR6L       h   M   ] C    E       g  filenamef  owner-report.scm
			 		
   C45(*8:<>@BDF, 9 Eh    ]H45 K454J>  "  G  44	5
54J>  "  G  4
54J>  "  G  4 54J>  "  G  4J>  "  G  44J5>  "  G  454J>  "  G  4 !54J>  "  G  4"#$54J>  "  G  4%&'54J>  "  G  4()*54J>  "  G  4+,-54J>  "  G  4./054J>  "  G  412354J>  "  G  44567485 54J>  "  G  49:;<==>? @AB  54J>  "  G  4CJD>  "  G  JC           g  acct-type-list
	 g  
owner-type	 g  reverse?		 g  gnc:*report-options*		 g  
new-option			4 g  
new-option		K	d g  
new-option		o  g  
new-option	   g  
new-option	  g  
new-option	!: g  
new-option	Ha g  
new-option	o g  
new-option	 g  
new-option	 g  
new-option	 g  
new-option	$ g  
new-option	6O g  
new-option	s  g  filenamef  owner-report.scm

			
			#		+		6		9							5		:	%	B	?	D		K		K		N		e		i		k	%	o		o		r	 	 	? 	 	 	 	 	 	% 	 	 	  	  	(  	 	 	 	 	 	 	 	 				
	
	!	!	$	;
	?	C	E	H
	H	K	b	f	j	l	o	o	r					
										!	"	#	#	!	 		&	'	(	(	
&	%		%+	+,	--	/-	0.	6+	6*	9	P1	X4	Z5	\6	^8	
`8	b8	*e8	g9	
i9	k9	,n9	q7	s1	s0	v	;	;	8;	 z		  g  nameg  options-generator CRG    h   |   ]  6  t       g  filenamef  owner-report.scm
?
		@		@	 		
  g  nameg  customer-options-generator C	R
   h   z   ]  6  r       g  filenamef  owner-report.scm
B
		C		C	 		
  g  nameg  vendor-options-generator CR
I      h   |   ]  6  t       g  filenamef  owner-report.scm
E
		F		F	 		
  g  nameg  employee-options-generator C
R       h   f   ] L C       ^       g  c
			  g  filenamef  owner-report.scm
J		J	!	J	 			   C     h   f   ] L C       ^       g  c
			  g  filenamef  owner-report.scm
L		L	-	L	( 			   C h`   #  ] (  C4LO  54LO  5(  "  45(  "  L 4L56        g  chars
		^ g  rest	'	: g  first	:	^ g  rest		:	^  g  filenamef  owner-report.scm
P		Q		
R		J		L		'L		/M		0N	
	7O	
	:S		AU		MV		OV	*	VW		^U	
 		^  g  nameg  line-helper C       h       ]O Q 4 56       g  string
		  g  	character		  g  replace-string			  g  line-helper			   g  filenamef  owner-report.scm
H
	X		 X	 		 	  g  nameg  
string-expand CR !"#        h   g  ]44554  >  "  G  4 	
 >  "  G  4 	 >  "  G  4 
>  "  G  4 
>  "  G  4 45 >  "  G   C     _      g  q
	  g  owner	  g  account		  g  end-date		  g  guid		   g  filenamef  owner-report.scm
Z
	[		[	#	[		[		]		 _		)]		2b		?d		Hb		Qf		`h		if		rl	 m	 n	 n	 n	 	 	  g  nameg  setup-query C$R%&'()*+,u-./       h     ]	45 4
 
 
 >  "  G  44	4
 5
5 >  "  G  4 >  "  G  4
 >  "  G  C             g  owner
	  g  table	   g  filenamef  owner-report.scm
q
	r		r		
s		t		u		u		u		v		v		 v		"w		$w		(w		-s		6x		;{		>{		H{	J	J{		Mz		Rx		[|		a~		d~		i|		r		x		z		|		~	 	 	 "	   g  nameg  make-owner-table C0R12     h(      ] 45445 5 6           g  table
		$ g  label		$ g  date			$  g  filenamef  owner-report.scm

			
									1			"		$	 		$	  g  nameg  make-date-row! C3R%&'(*u-./    hP     ]45  4 
 
 >  "  G  4 	
 >  "  G   C   
      g  table
		M  g  filenamef  owner-report.scm

					
														 		%		.		4		6		8		:		=		B	 		M
  g  nameg  make-date-table C4R56789:%&'(;<./)*,=>?    h     ]"45 4 544 5544 554	

 
  
 
 >  "  G  4$  "   >  "  G  44$  "  
5 >  "  G  44445 55 >  "  G  C       g  book
	  g  date-format	  g  table		  g  slots		  g  name		'  g  addy		>   g  filenamef  owner-report.scm

					
								#		%		'		'		*		/		:		<		>		>		A		G		I		K		O		Q		S		U		X		Z		\		^		a		c		e		i		k		m		q		v			 	, 	: 	& 	 	 	, 	 	' 	# 	, 	& 	 	 	 	 	$ 	 	 	 	& 	 <	 	  g  nameg  make-myname-table C@RAB   h      ] 445 56             g  document
		  g  filenamef  owner-report.scm

			
					 		  g  nameg  make-break! CCRDE64FGH5(I*#L,\JMKLMNAZO$PQRSTU%&'()*@0CVWXW 7   h  !  ]i45 H45 444 55544	
444 5555544	

444 5555545 444 55545	

444 5
55

444 5	55445455H45$ 4J455K(  $44J4 55>  "  G  " |4>  "  G  4J>  "  G  4 4!"454#54$4%54555>  "  G  4&4 5
5K4'J()* )+
 ),	 >  "  G  44-

444 5
.55
5>  "  G  44/5>  "  G  40>  "  G  4414425435443555>  "  G  40>  "  G  4J>  "  G  45>  "  G  "   446J4 55>  "  G  C             g  
report-obj
	 g  document	 g  table		
 g  query		 g  section			6 g  name			6 g  account		6 g  section		B	a g  name		B	a g  
start-date		e g  section		q  g  name		q  g  end-date	  g  book	  g  type	  g  owner-descr		  g  section	
   g  name	   g  	date-type	
  g  section	   g  owner	  g  report-title	 g  section	
3  g  filenamef  owner-report.scm

					
		
		
										"		.		0		6		9		<		B		G		J		M		Y		[		c		e		e		h		k		q		v		y		|	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 			"	5
	9	<	9			
"	#	)	5*	:2	4	:	;	@	E	M	R	_	w										%								$															 						!		"	,	C.	0	5		:	C	H		S	\	n	s 		v	
y	}							
 				
							 	  g  nameg  reg-renderer CYRZ[\]   hp     ])"  ;$  C4545 &  C"45 45
$  
"C            g  type
		j g  account		A g  num			A g  index			A g  
this-child			A g  account-type		#	A g  current-root	F	j g  num-accounts		O	j  g  filenamef  owner-report.scm

															#		-		7	"	A	
	B		F		I		O		U		Y		h		i	 		j  g  nameg  find-first-account C^R_G^
I`a       hX   3  ]	44 55$  6$  6$  6	$  
4 56C     +      g  owner
		S g  type		S  g  filenamef  owner-report.scm

									!		 		"		$$		( 		.%		3'		7 		=(		B*		F 		I+	%	Q+		R.	 		S  g  nameg  find-first-account-for-owner CaR4bicdef2ighi 	iiYij>  "  G  4bicdkf0ighi iiYij>  "  G  4bicdlf.ighi 
iiYij>  "  G  m6L4n    h`   l  ]4 54455454>  "  G  4>  "  G   6      d      g  report-guid
		Z g  owner		Z g  account			Z g  
owner-type			Z g  options				Z g  owner-op			Z g  
account-op		(	Z  g  filenamef  owner-report.scm
K
	L			L		M		M	5	M		L		N		(L		+P		?Q		ZR	 
		Z	  g  nameg  owner-report-create-internal CoR_Go20I. 
     hX     ]
44 55$   6$   6$  	 6C             g  owner
		Q g  account		Q g  type			Q  g  filenamef  owner-report.scm
T
	U		U		U		U		W		V		%X		*Z		.V		:[		?]		CV		O^	 		Q	  g  nameg  owner-report-create CpRqrst hH     , 3 45 45		H
	(  "  4	 5K
4>  "  G  J
C        g  account
		F g  split		F g  query			F g  journal?			F g  double?			F g  title			F g  debit-string			F g  
credit-string			F g  
temp-owner			F g  owner				F g  res	
		F  g  filenamef  owner-report.scm
b
	f		f		g		f		"j		'k		1k		2m	 
		F	  g  nameg   gnc:owner-report-create-internal CuR4viiui>  "  G  4vi
iui>  "  G  y|     h   C   ] 45 6   ;       g  filenamef  owner-report.scm
v
 		
   C6   b      g  m
	
	$  g  filenamef  owner-report.scm		
	%	
	:	
	O	
	d	
	y	!
		!	 	!
 	"
 	#
 	&	 	&
 	'	 	'
 	(	  	(
 	+	 	+
 	,	 	,
 	-	 	-
 	/	 	/
 	0
 	1	 	1
 	2	 	2
 	3	 	3
 	4	 	4
 	5	 	5
 	6	 	6
	7		7
	8			8
	D
		K
#	Q
	X
	`
	j

	s

	z
A	|
	~
g 
 

 
0 
 
 

 

 
 
 
 
 
# 
'
*.
1ZB
>|
I 
I?
JnB
KE
NH
Q;Z
Sq
T
V
Z
[
gm
i
kw
kx0
k1k2k2	k3k4k4	k5k6k7k0
k9
k:k;k;	k<k=k=	k>k?k@k9
kB
lCl
Dl
D	lElFlF	l"Gl*Hl2Il8B
n0K
oT
qb
qp
qs
r}v
 z	r}
   C6 